gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r28232 - in gnunet/src: include tun vpn


From: gnunet
Subject: [GNUnet-SVN] r28232 - in gnunet/src: include tun vpn
Date: Mon, 22 Jul 2013 09:18:25 +0200

Author: grothoff
Date: 2013-07-22 09:18:25 +0200 (Mon, 22 Jul 2013)
New Revision: 28232

Modified:
   gnunet/src/include/gnunet_tun_lib.h
   gnunet/src/tun/regex.c
   gnunet/src/tun/test_regex.c
   gnunet/src/vpn/gnunet-service-vpn.c
Log:
rename GNUNET_TUN_ipvXtoregex to GNUNET_TUN_ipvXtoregexsearch to clarify that 
this is for generating the search strings

Modified: gnunet/src/include/gnunet_tun_lib.h
===================================================================
--- gnunet/src/tun/test_regex.c 2013-07-22 07:16:58 UTC (rev 28231)
+++ gnunet/src/tun/test_regex.c 2013-07-22 07:18:25 UTC (rev 28232)
@@ -39,7 +39,7 @@
   char rxv6[GNUNET_TUN_IPV6_REGEXLEN];
 
   GNUNET_assert (1 == inet_pton (AF_INET, ipv4, &a));
-  GNUNET_TUN_ipv4toregex (&a, netmask, rxv4);
+  GNUNET_TUN_ipv4toregexsearch (&a, netmask, rxv4);
 
 
   if (0 != strcmp (rxv4, expectedv4))
@@ -50,7 +50,7 @@
   }
 
   GNUNET_assert (1 == inet_pton (AF_INET6, ipv6, &b));
-  GNUNET_TUN_ipv6toregex (&b, prefixlen, rxv6);
+  GNUNET_TUN_ipv6toregexsearch (&b, prefixlen, rxv6);
 
   if (0 != strcmp (rxv6, expectedv6))
   {

Modified: gnunet/src/vpn/gnunet-service-vpn.c
===================================================================
--- gnunet/src/vpn/gnunet-service-vpn.c 2013-07-22 07:16:58 UTC (rev 28231)
+++ gnunet/src/vpn/gnunet-service-vpn.c 2013-07-22 07:18:25 UTC (rev 28232)
@@ -855,7 +855,7 @@
     {
       char address[GNUNET_TUN_IPV4_REGEXLEN];
 
-      GNUNET_TUN_ipv4toregex (&de->details.exit_destination.ip.v4,
+      GNUNET_TUN_ipv4toregexsearch (&de->details.exit_destination.ip.v4,
                   "255.255.255.255", address);
       GNUNET_asprintf (&policy, "%s%s%s",
                        GNUNET_APPLICATION_TYPE_EXIT_REGEX_PREFIX,
@@ -867,7 +867,7 @@
     {
       char address[GNUNET_TUN_IPV6_REGEXLEN];
       
-      GNUNET_TUN_ipv6toregex (&de->details.exit_destination.ip.v6,
+      GNUNET_TUN_ipv6toregexsearch (&de->details.exit_destination.ip.v6,
                   128, address);
       GNUNET_asprintf (&policy, "%s%s%s",
                        GNUNET_APPLICATION_TYPE_EXIT_REGEX_PREFIX,




reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- gnunet/src/include/gnunet_tun_lib.h 2013-07-22 07:16:58 UTC (rev 28231)
+++ gnunet/src/include/gnunet_tun_lib.h 2013-07-22 07:18:25 UTC (rev 28232)
@@ -47,13 +47,13 @@
 
 
 /**
  * Maximum regex string length for use with GNUNET_TUN_ipv4toregex
  */
 #define GNUNET_TUN_IPV4_REGEXLEN 32 + 6
 
 
 /**
  * Maximum regex string length for use with GNUNET_TUN_ipv6toregex
  */
 #define GNUNET_TUN_IPV6_REGEXLEN 128 + 6
 
@@ -438,7 +438,7 @@
  *              bytes long.
  */
 void
-GNUNET_TUN_ipv4toregex (const struct in_addr *ip, const char *netmask,
+GNUNET_TUN_ipv4toregexsearch (const struct in_addr *ip, const char *netmask,
                        char *rxstr);
 
 
@@ -451,7 +451,7 @@
  *              bytes long.
  */
 void
-GNUNET_TUN_ipv6toregex (const struct in6_addr *ipv6,
+GNUNET_TUN_ipv6toregexsearch (const struct in6_addr *ipv6,
                        unsigned int prefixlen, char *rxstr);
 
 
@@ -459,7 +459,7 @@
  * Convert an exit policy to a regular expression.  The exit policy
  * specifies a set of subnets this peer is willing to serve as an
  * exit for; the resulting regular expression will match the
  * IPv6 address strings as returned by 'GNUNET_TUN_ipv6toregex'.
  *
  * @param policy exit policy specification
  * @return regular expression, NULL on error
@@ -472,7 +472,7 @@
  * Convert an exit policy to a regular expression.  The exit policy
  * specifies a set of subnets this peer is willing to serve as an
  * exit for; the resulting regular expression will match the
  * IPv4 address strings as returned by 'GNUNET_TUN_ipv4toregex'.
  *
  * @param policy exit policy specification
  * @return regular expression, NULL on error
@@ -47,13 +47,13 @@
 
 /**
- * Maximum regex string length for use with GNUNET_TUN_ipv4toregex
+ * Maximum regex string length for use with GNUNET_TUN_ipv4toregexsearch
  */
 #define GNUNET_TUN_IPV4_REGEXLEN 32 + 6
@@ -47,13 +47,13 @@
 
 /**
- * Maximum regex string length for use with GNUNET_TUN_ipv6toregex
+ * Maximum regex string length for use with GNUNET_TUN_ipv6toregexsearch
  */
 #define GNUNET_TUN_IPV6_REGEXLEN 128 + 6
@@ -459,7 +459,7 @@
  * specifies a set of subnets this peer is willing to serve as an
  * exit for; the resulting regular expression will match the
- * IPv6 address strings as returned by 'GNUNET_TUN_ipv6toregex'.
+ * IPv6 address strings as returned by 'GNUNET_TUN_ipv6toregexsearch'.
  *
  * @param policy exit policy specification
@@ -472,7 +472,7 @@
  * specifies a set of subnets this peer is willing to serve as an
  * exit for; the resulting regular expression will match the
- * IPv4 address strings as returned by 'GNUNET_TUN_ipv4toregex'.
+ * IPv4 address strings as returned by 'GNUNET_TUN_ipv4toregexsearch'.
  *
  * @param policy exit policy specification

Modified: gnunet/src/tun/regex.c
===================================================================
--- gnunet/src/tun/regex.c      2013-07-22 07:16:58 UTC (rev 28231)
+++ gnunet/src/tun/regex.c      2013-07-22 07:18:25 UTC (rev 28232)
@@ -107,7 +107,7 @@
  *              bytes long.
  */
 void
-GNUNET_TUN_ipv4toregex (const struct in_addr *ip, const char *netmask,
+GNUNET_TUN_ipv4toregexsearch (const struct in_addr *ip, const char *netmask,
                        char *rxstr)
 {
   unsigned int pfxlen;
@@ -129,7 +129,7 @@
  *              bytes long.
  */
 void
-GNUNET_TUN_ipv6toregex (const struct in6_addr *ipv6, unsigned int prefixlen,
+GNUNET_TUN_ipv6toregexsearch (const struct in6_addr *ipv6, unsigned int 
prefixlen,
                        char *rxstr)
 {
   iptobinstr (AF_INET6, ipv6, rxstr);
@@ -143,7 +143,7 @@
  * Convert an exit policy to a regular expression.  The exit policy
  * specifies a set of subnets this peer is willing to serve as an
  * exit for; the resulting regular expression will match the
  * IPv4 address strings as returned by 'GNUNET_TUN_ipv4toregex'.
  *
  * @param policy exit policy specification
  * @return regular expression, NULL on error
@@ -159,7 +159,7 @@
  * Convert an exit policy to a regular expression.  The exit policy
  * specifies a set of subnets this peer is willing to serve as an
  * exit for; the resulting regular expression will match the
  * IPv4 address strings as returned by 'GNUNET_TUN_ipv4toregex'.
  *
  * @param policy exit policy specification
  * @return regular expression, NULL on error
@@ -143,7 +143,7 @@
  * specifies a set of subnets this peer is willing to serve as an
  * exit for; the resulting regular expression will match the
- * IPv4 address strings as returned by 'GNUNET_TUN_ipv4toregex'.
+ * IPv4 address strings as returned by 'GNUNET_TUN_ipv4toregexsearch'.
  *
  * @param policy exit policy specification
@@ -159,7 +159,7 @@
  * specifies a set of subnets this peer is willing to serve as an
  * exit for; the resulting regular expression will match the
- * IPv4 address strings as returned by 'GNUNET_TUN_ipv4toregex'.
+ * IPv4 address strings as returned by 'GNUNET_TUN_ipv4toregexsearch'.
  *
  * @param policy exit policy specification

Modified: gnunet/src/tun/test_regex.c
===================================================================